@@ -165,9 +165,10 @@ fn mark_dir_as_hidden(path: &path::Path) {
 #[cfg(windows)]
 #[allow(unsafe_code)]
 fn mark_dir_as_hidden_impl(path: &ffi::OsStr) -> Result<(), u32> {
-	use std::os::windows::prelude::*;
-	use winapi::um::{
-		errhandlingapi::GetLastError, fileapi::SetFileAttributesW, winnt::FILE_ATTRIBUTE_HIDDEN,
+	use std::os::windows::ffi::OsStrExt;
+	use windows_sys::Win32::{
+		Foundation::GetLastError,
+		Storage::FileSystem::{SetFileAttributesW, FILE_ATTRIBUTE_HIDDEN},
 	};
 
 	let path = path.encode_wide().chain(Some(0)).collect::<Vec<u16>>();
