@@ -5,6 +5,7 @@ use crate::num::dist::Dist;
 use crate::num::{Base, FormattingStyle};
 use crate::scope::Scope;
 use crate::serialize::{deserialize_bool, deserialize_usize, serialize_bool, serialize_usize};
+use crate::units::{lookup_default_unit, query_unit_static};
 use crate::{ast, ident::Ident};
 use crate::{Attrs, Span, SpanKind};
 use std::borrow::Cow;
@@ -72,14 +73,21 @@ impl Value {
 	pub(crate) fn create_unit_value_from_value<I: Interrupt>(
 		value: &Self,
 		prefix: Cow<'static, str>,
+		alias: bool,
 		singular_name: Cow<'static, str>,
 		plural_name: Cow<'static, str>,
 		int: &I,
 	) -> Result<Self, FendError> {
 		let (hashmap, scale) = value.unit.to_hashmap_and_scale(int)?;
 		let scale = scale.mul(&Exact::new(value.value.one_point_ref()?.clone(), true), int)?;
-		let resulting_unit =
-			NamedUnit::new(prefix, singular_name, plural_name, hashmap, scale.value);
+		let resulting_unit = NamedUnit::new(
+			prefix,
+			singular_name,
+			plural_name,
+			alias,
+			hashmap,
+			scale.value,
+		);
 		let mut result = Self::new(1, vec![UnitExponent::new(resulting_unit, 1)]);
 		result.exact = result.exact && value.exact && scale.exact;
 		Ok(result)
@@ -92,7 +100,14 @@ impl Value {
 		let base_unit = BaseUnit::new(singular_name.clone());
 		let mut hashmap = HashMap::new();
 		hashmap.insert(base_unit, 1.into());
-		let unit = NamedUnit::new(Cow::Borrowed(""), singular_name, plural_name, hashmap, 1);
+		let unit = NamedUnit::new(
+			Cow::Borrowed(""),
+			singular_name,
+			plural_name,
+			false,
+			hashmap,
+			1,
+		);
 		Self::new(1, vec![UnitExponent::new(unit, 1)])
 	}
 
@@ -335,7 +350,7 @@ impl Value {
 		}
 	}
 
-	fn is_unitless<I: Interrupt>(&self, int: &I) -> Result<bool, FendError> {
+	pub(crate) fn is_unitless<I: Interrupt>(&self, int: &I) -> Result<bool, FendError> {
 		// todo this is broken for unitless components
 		if self.unit.components.is_empty() {
 			return Ok(true);
@@ -713,7 +728,13 @@ impl Value {
 		})
 	}
 
-	pub(crate) fn simplify<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
+	#[allow(clippy::too_many_lines)]
+	pub(crate) fn simplify<I: Interrupt>(
+		self,
+		attrs: Attrs,
+		ctx: &mut crate::Context,
+		int: &I,
+	) -> Result<Self, FendError> {
 		if !self.simplifiable {
 			return Ok(self);
 		}
@@ -722,57 +743,25 @@ impl Value {
 		let mut res_exact = self.exact;
 		let mut res_value = self.value;
 
-		/*
-		 * In fend, percentages are units.
-		 * Without any special handling, multiplication would
-		 * unconditionally combine them.
-		 *
-		 * This would (and did) lead to unexpected results,
-		 * that fell into two broad categories:
-		 * 1. mixing percentages with units: `80 kg * 5% = 400 kg %`.
-		 * 2. percenteges squared: "5% * 5% = 25%^2"
-		 *
-		 * In practice, percentages are usually used as scalar multipliers,
-		 * not as "units" in the traditional sense.
-		 *
-		 * To avoid this, we have the following rules
-		 * for simplifying percentages.
-		 *
-		 * 1. If there are any other units (kg, lbs, etc..),
-		 *    then all of the percentages are removed (fixing first problem)
-		 * 2. No more than one "percentage unit" is permitted.
-		 *
-		 * This (mostly) fixes issue #164
-		 *
-		 * There is still some ambiguity here even after
-		 * going through these rules (although this fixes most of it).
-		 * See discussion on the "5_percent_times_100" test for more details.
-		 */
-		let mut have_percentage_unit = false;
-		let has_nonpercentage_components =
-			self.unit.components.iter().any(|u| !u.is_percentage_unit());
-		// combine identical or compatible units by summing their exponents
-		// and potentially adjusting the value
+		// remove alias units and combine identical or compatible units
+		// by summing their exponents and potentially adjusting the value
 		'outer: for comp in self.unit.components {
-			if comp.is_percentage_unit() {
-				if have_percentage_unit || has_nonpercentage_components {
-					let adjusted_res = Exact {
-						value: res_value,
-						exact: res_exact,
-					}
-					.mul(
-						&Exact {
-							value: comp.unit.scale.clone().into(),
-							exact: true,
-						},
-						int,
-					)?;
-					res_value = adjusted_res.value;
-					res_exact = adjusted_res.exact;
-					continue 'outer;
+			if comp.is_alias() {
+				// remove alias units
+				let adjusted_res = Exact {
+					value: res_value,
+					exact: res_exact,
 				}
-				// already encountered one (if we see another one, strip it)
-				have_percentage_unit = true;
+				.mul(
+					&Exact {
+						value: comp.unit.scale.clone().into(),
+						exact: true,
+					},
+					int,
+				)?;
+				res_value = adjusted_res.value;
+				res_exact = adjusted_res.exact;
+				continue;
 			}
 			for res_comp in &mut res_components {
 				if comp.unit.has_no_base_units() && comp.unit != res_comp.unit {
@@ -833,8 +822,7 @@ impl Value {
 
 		// remove units with exponent == 0
 		res_components.retain(|unit_exponent| unit_exponent.exponent != 0.into());
-
-		Ok(Self {
+		let result = Self {
 			value: res_value,
 			unit: Unit {
 				components: res_components,
@@ -843,7 +831,31 @@ impl Value {
 			base: self.base,
 			format: self.format,
 			simplifiable: self.simplifiable,
-		})
+		};
+
+		if result.unit.components.len() > 1
+			&& !result
+				.unit
+				.components
+				.iter()
+				.any(|c| c.unit.singular_name == "rad" || c.unit.singular_name == "radian")
+		{
+			// try and replace unit with a default one, e.g. `kilogram` or `ampere`
+			let (hashmap, _) = result.unit.to_hashmap_and_scale(int)?;
+			if let Ok(mut base_units) = hashmap
+				.into_iter()
+				.map(|(k, v)| v.try_as_i64(int).map(|v| format!("{}^{v}", k.name())))
+				.collect::<Result<Vec<String>, _>>()
+			{
+				base_units.sort();
+				if let Some(new_unit) = lookup_default_unit(&base_units.join(" ")) {
+					let rhs = query_unit_static(new_unit, attrs, ctx, int)?.expect_num()?;
+					return result.convert_to(rhs, int);
+				}
+			}
+		}
+
+		Ok(result)
 	}
 
 	pub(crate) fn unit_equal_to(&self, rhs: &str) -> bool {
@@ -986,7 +998,7 @@ impl Unit {
 		prefix.is_empty() && name == rhs
 	}
 
-	/// guarantees that base units with an cancelled exponents do not appear in the hashmap
+	/// base units with cancelled exponents do not appear in the hashmap
 	fn to_hashmap_and_scale<I: Interrupt>(&self, int: &I) -> Result<HashmapScale, FendError> {
 		let mut hashmap = HashMap::<BaseUnit, Complex>::new();
 		let mut scale = Complex::from(1);
@@ -1217,7 +1229,7 @@ mod tests {
 		let base_kg = BaseUnit::new("kilogram".into());
 		let mut hashmap = HashMap::new();
 		hashmap.insert(base_kg, 1.into());
-		let kg = NamedUnit::new("k".into(), "g".into(), "g".into(), hashmap, 1);
+		let kg = NamedUnit::new("k".into(), "g".into(), "g".into(), false, hashmap, 1);
 		let one_kg = Value::new(1, vec![UnitExponent::new(kg.clone(), 1)]);
 		let two_kg = Value::new(2, vec![UnitExponent::new(kg, 1)]);
 		let sum = one_kg.add(two_kg, &Never).unwrap();
@@ -1230,11 +1242,19 @@ mod tests {
 		let base_kg = BaseUnit::new("kilogram".into());
 		let mut hashmap = HashMap::new();
 		hashmap.insert(base_kg, 1.into());
-		let kg = NamedUnit::new("k".into(), "g".into(), "g".into(), hashmap.clone(), 1);
+		let kg = NamedUnit::new(
+			"k".into(),
+			"g".into(),
+			"g".into(),
+			false,
+			hashmap.clone(),
+			1,
+		);
 		let g = NamedUnit::new(
 			Cow::Borrowed(""),
 			Cow::Borrowed("g"),
 			Cow::Borrowed("g"),
+			false,
 			hashmap,
 			Exact::new(Complex::from(1), true)
 				.div(Exact::new(1000.into(), true), int)
