@@ -8,6 +8,7 @@ use crate::Attrs;
 
 mod builtin;
 
+pub(crate) use builtin::lookup_default_unit;
 pub(crate) use builtin::IMPLICIT_UNIT_MAP;
 
 #[derive(Copy, Clone, Eq, PartialEq, Debug)]
@@ -24,6 +25,7 @@ pub(crate) struct UnitDef {
 	singular: Cow<'static, str>,
 	plural: Cow<'static, str>,
 	prefix_rule: PrefixRule,
+	alias: bool,
 	value: Value,
 }
 
@@ -51,6 +53,7 @@ fn expr_unit<I: Interrupt>(
 		let value = Number::create_unit_value_from_value(
 			&value,
 			Cow::Borrowed(""),
+			false,
 			singular.clone(),
 			plural.clone(),
 			int,
@@ -59,6 +62,7 @@ fn expr_unit<I: Interrupt>(
 			singular,
 			plural,
 			prefix_rule: PrefixRule::LongPrefixAllowed,
+			alias: false,
 			value: Value::Num(Box::new(value)),
 		});
 	}
@@ -88,16 +92,38 @@ fn expr_unit<I: Interrupt>(
 			prefix_rule: rule,
 			singular,
 			plural,
+			alias: false,
 		});
 	}
 	let (alias, definition) = definition
 		.strip_prefix('=')
 		.map_or((false, definition), |remaining| (true, remaining));
+	// long prefixes like `hecto` are always treated as aliases
+	let alias = alias || rule == PrefixRule::LongPrefix;
 	let mut num = evaluate_to_value(definition, None, attrs, context, int)?.expect_num()?;
-	if !alias && rule != PrefixRule::LongPrefix {
+
+	// There are three cases to consider:
+	//   1. Unitless aliases (e.g. `million` or `mega`) should be treated as an
+	//      actual unit, but with the `alias` flag set so it can be simplified
+	//      when possible.
+	//   2. Aliases with units (e.g. `sqft`) should be a pure alias (not a unit)
+	//      so it can always be replaced. We can't convert this like unitless
+	//      aliases since we would be simplifying it to base units (scaled m^2),
+	//      so the precise unit we are aliasing to would be lost.
+	//   3. Units that aren't aliased (e.g. `meter`) should be converted to a
+	//      normal unit.
+	//
+	// One exception to these cases is `unitless`, which should always be
+	// replaced with `1` even when we aren't simplifying, so it is defined
+	// manually instead of as a normal unit definition.
+
+	#[allow(clippy::nonminimal_bool)]
+	if !alias || (alias && num.is_unitless(int)?) {
+		// convert to an actual unit (cases 1 and 3)
 		num = Number::create_unit_value_from_value(
 			&num,
 			Cow::Borrowed(""),
+			alias,
 			singular.clone(),
 			plural.clone(),
 			int,
@@ -108,6 +134,7 @@ fn expr_unit<I: Interrupt>(
 		prefix_rule: rule,
 		singular,
 		plural,
+		alias,
 	})
 }
 
@@ -118,8 +145,9 @@ fn construct_prefixed_unit<I: Interrupt>(
 ) -> Result<Value, FendError> {
 	let product = a.value.expect_num()?.mul(b.value.expect_num()?, int)?;
 	assert_eq!(a.singular, a.plural);
-	let unit =
-		Number::create_unit_value_from_value(&product, a.singular, b.singular, b.plural, int)?;
+	let unit = Number::create_unit_value_from_value(
+		&product, a.singular, b.alias, b.singular, b.plural, int,
+	)?;
 	Ok(Value::Num(Box::new(unit)))
 }
 
