@@ -11,7 +11,6 @@ struct UnitDef {
 type UnitTuple = (&'static str, &'static str, &'static str, &'static str);
 
 const BASE_UNITS: &[UnitTuple] = &[
-	("unitless", "", "=1", ""),
 	("second", "seconds", "l@!", ""),
 	("meter", "meters", "l@!", ""),
 	("kilogram", "kilograms", "l@!", ""),
@@ -432,9 +431,9 @@ const TIME_UNITS: &[UnitTuple] = &[
 ];
 
 const RATIOS: &[UnitTuple] = &[
-	("\u{2030}", "", "0.001", ""), // per mille
-	("percent", "", "0.01", ""),
-	("%", "", "percent", ""),
+	("\u{2030}", "", "=0.001", ""), // per mille
+	("percent", "", "=0.01", ""),
+	("%", "", "=percent", ""),
 	("bel", "bels", "0.5 * ln(10) neper", ""),
 	("decibel", "decibels", "1/10 bel", ""),
 	("dB", "", "decibel", ""),
@@ -473,6 +472,7 @@ const COMMON_PHYSICAL_UNITS: &[UnitTuple] = &[
 	("cc", "", "cm^3", ""),
 	("are", "ares", "l@100 meter^2", ""),
 	("liter", "liters", "l@1000 cc", ""),
+	("litre", "litres", "liter", ""),
 	("l", "", "s@liter", ""),
 	("L", "", "s@liter", ""),
 	("micron", "microns", "l@micrometer", ""),
@@ -835,6 +835,30 @@ pub(crate) fn query_unit(
 	None
 }
 
+const DEFAULT_UNITS: &[(&str, &str)] = &[
+	("hertz", "second^-1"),
+	("newton", "kilogram^1 meter^1 second^-2"),
+	("pascal", "kilogram^1 meter^-1 second^-2"),
+	("joule", "kilogram^1 meter^2 second^-2"),
+	("watt", "kilogram^1 meter^2 second^-3"),
+	("ohm", "ampere^-2 kilogram^1 meter^2 second^-3"),
+	("volt", "ampere^-1 kilogram^1 meter^2 second^-3"),
+	("liter", "meter^3"),
+];
+
+pub(crate) fn lookup_default_unit(base_units: &str) -> Option<&str> {
+	if let Some((unit_name, _)) = DEFAULT_UNITS.iter().find(|(_, base)| *base == base_units) {
+		return Some(unit_name);
+	}
+	if let Some((singular, _, _, _)) = BASE_UNITS
+		.iter()
+		.find(|(singular, _, _, _)| format!("{singular}^1") == base_units)
+	{
+		return Some(singular);
+	}
+	None
+}
+
 /// used for implicit unit addition, e.g. 5'5 -> 5'5"
 pub(crate) const IMPLICIT_UNIT_MAP: &[(&str, &str)] = &[("'", "\""), ("foot", "inches")];
 
