@@ -2094,17 +2094,22 @@ fn three_meters_15_cm() {
 
 #[test]
 fn five_percent() {
-	test_eval("5%", "5%");
+	test_eval("5%", "0.05");
+}
+
+#[test]
+fn five_percent_to_percent() {
+	test_eval_simple("5% to %", "5%");
 }
 
 #[test]
 fn five_percent_plus_point_one() {
-	test_eval("5% + 0.1", "15%");
+	test_eval("5% + 0.1", "0.15");
 }
 
 #[test]
 fn five_percent_plus_one() {
-	test_eval("5% + 1", "105%");
+	test_eval("5% + 1", "1.05");
 }
 
 #[test]
@@ -2119,7 +2124,7 @@ fn one_plus_five_percent() {
 
 #[test]
 fn five_percent_times_five_percent() {
-	test_eval("5% * 5%", "0.25%");
+	test_eval("5% * 5%", "0.0025");
 }
 
 #[test]
@@ -2129,33 +2134,11 @@ fn five_percent_times_kg() {
 
 #[test]
 fn five_percent_times_100() {
-	/*
-	 * as discussed in the "simplify" function,
-	 * there are two ways to view this:
-	 *
-	 * 1. 5% of 100 (giving 5)
-	 * 2. 100x 5% (giving 500%)
-	 *
-	 * Mathematically they are equivalent values.
-	 * However, from a UI perspective they are not.
-	 *
-	 * I (Techcable) suggest overloading the "of" operator for that purpose.
-	 * For example "5% of 100 => 5".
-	 *
-	 * This would work for all values, and would specifically require that the
-	 * left side is formatted as a percentage.
-	 */
-	test_eval("5% * 100", "500%");
+	test_eval("5% * 100", "5");
 }
 
 #[test]
 fn five_percent_of_100() {
-	// Continuing the discussion in the previous test
-	// We handle the overloading in the evaluate function
-	// If we encounter an Of with a percent in the LHS
-	// Then we divide the LHS with 100 and multiply it with RHS
-	// Discarding the percent in the process
-
 	test_eval("5% of 100", "5");
 }
 
@@ -2211,7 +2194,7 @@ fn units_10() {
 
 #[test]
 fn units_11() {
-	test_eval("1 light year", "1 light year");
+	test_eval("1 light year", "1 light_year");
 }
 
 #[test]
@@ -2296,7 +2279,7 @@ fn units_33() {
 
 #[test]
 fn units_34() {
-	test_eval("1 light year", "1 light year");
+	test_eval("0.5 light year", "0.5 light_years");
 }
 
 #[test]
@@ -4475,10 +4458,9 @@ fn test_hex_unit_conversion_complex() {
 	test_eval_simple("i yard lb to hex to kg m to 3sf", "approx. 0.6a2 i kg m");
 }
 
-#[ignore]
 #[test]
 fn convert_to_billion() {
-	test_eval("1000000000 to billion", "1 billion");
+	test_eval_simple("1000000000 to billion", "1 billion");
 }
 
 #[test]
@@ -5193,7 +5175,7 @@ fn single_line_comment_and_linebreak_3() {
 
 #[test]
 fn percent_plus_per_mille() {
-	test_eval("4% + 3\u{2030}", "4.3%");
+	test_eval("4% + 3\u{2030}", "0.043");
 }
 
 #[test]
@@ -5810,3 +5792,33 @@ fn hubble_constant() {
 		"approx. 0.0000000000000000022685455 s^-1",
 	);
 }
+
+#[test]
+fn oc() {
+	test_eval("5 oC", "5 °C");
+}
+
+#[test]
+fn to_million() {
+	test_eval_simple("5 to million", "0.000005 million");
+}
+
+#[test]
+fn ohms_law() {
+	test_eval("(5 volts) / (2 ohms)", "2.5 amperes");
+}
+
+#[test]
+fn simplification_sec_hz() {
+	test_eval("c/(145MHz)", "approx. 2.0675341931 meters");
+}
+
+#[test]
+fn simplification_ohms() {
+	test_eval("4556 ohm * ampere", "4556 volts");
+}
+
+#[test]
+fn simplification_ohms_2() {
+	test_eval("4556 volt / ampere", "4556 ohms");
+}
